import { CancelOrderApi } from "@/api/order"
import { alert } from "@/common/common"
import { View } from "@tarojs/components"
import Taro from "@tarojs/taro"
import { useCallback, useRef, memo } from "react"
import styles  from './index.module.scss'

type Param = {
    orderInfo: {
        status?: number, //订单状态
        orderId: number, //订单id
        payModel: number, //支付方式
        realPayPrice: number, //实付金额
        pendingPayPrice: number, //待付金额
    },
    onClick?: (val: number) => void //点击后触发的事件，返回订单状态
}
export default memo(({orderInfo, onClick}:Param) => {
    //订单按钮按订单状态归类
    const orderBtnsList = useRef([
        {
            id: 1,
            value: [0, 1, 2, 3, 4], //取消订单按钮对应： 待接单，待配布，已配布, 待付款， 待发货
            label: '取消订单'
        },
        {
            id: 2,
            value: [3, 4], //去付款按钮对应：待付款， 待发货
            label: '去付款'
        },
        {
            id: 3,
            value: [4], //取消订单按钮对应： 待发货
            label: '申请退款'
        },
        {
            id: 4,
            value: [5, 6, 7, 8], //取消订单按钮对应： 待收货, 已收货, 已完成, 已退款
            label: '查看物流'
        },
        {
            id: 5,
            value: [5, 6, 8], //取消订单按钮对应： 待收货, 已收货, 已退款
            label: '申请退货'
        },
        {
            id: 6,
            value: [5], //取消订单按钮对应： 待收货
            label: '确认收货'
        },
        {
            id: 7,
            value: [5,6,7,8], //取消订单按钮对应： 待收货，已收货，已完成, 已退款
            label: '再次购买'
        }
    ])
    //判断是否显示该按钮
    const orderBtnsShow = useCallback((item, status) => {
        if(item.id == 1) {
           return( orderInfo.realPayPrice == 0 && status <= 4) //在代发货之前没有付过款
        } 
        if(item.id == 2) {
            return( orderInfo.pendingPayPrice != 0 && status <= 4) //在代发货之前没有付完款
        }
        return item.value.includes(status)
    },[])

    //点击按钮操作
    const submitBtns = (val) => {
        (val == 1)&&cancelOrder(); //取消订单按钮
        (val == 2)&&onClick?.(val); //去付款按钮
    }

    //取消订单
    const {fetchData: cancelFetchData} = CancelOrderApi()
    const cancelOrder = () => {
        Taro.showModal({
            title: '要取消该订单吗？',
            success: async function (res) {
              if (res.confirm) {
                let res = await cancelFetchData({id: orderInfo.orderId})
                if(res.success) {
                    alert.success('取消成功')
                    onClick?.(1)
                } else {
                    alert.none(res.msg)
                }
              } else if (res.cancel) {
                console.log('用户点击取消')
              }
            }
          })
    }

    return (
        <View className={styles.btns_list}>
            {orderBtnsList.current.map((item, index) => 
                orderBtnsShow(item, status)&&<View className={styles.btns_item} onClick={() => submitBtns(item.id)}>{item.label}</View>
            )}
        </View>
    )
})